@@ -131,6 +131,9 @@ static bool pmt_utabent_matches(const struct vol *vpt, struct libmnt_fs *fs)
 		}
 	}
 
+	if (vpt->ignore_source)
+		result = true;
+
 	if (target != NULL)
 		result &= strcmp(vpt->mountpoint, target) == 0;
 
@@ -256,14 +259,14 @@ static void log_pm_input(const struct config *const config,
 		"Mount info: %s, user=%s <volume fstype=\"%s\" "
 		"server=\"%s\" path=\"%s\" "
 		"mountpoint=\"%s\" cipher=\"%s\" fskeypath=\"%s\" "
-		"fskeycipher=\"%s\" fskeyhash=\"%s\" header=\"%s\" options=\"%s\" /> "
-		"fstab=%u ssh=%u\n",
+		"fskeycipher=\"%s\" fskeyhash=\"%s\" header=\"%s\" options=\"%s\" "
+		"fstab=%u ssh=%u ignoresource=%u /> \n",
 		vpt->globalconf ? "globalconf" : "luserconf",
 		znul(vpt->user), znul(vpt->fstype),
 		znul(vpt->server), znul(vpt->volume),
 		vpt->mountpoint, znul(vpt->cipher), znul(vpt->fs_key_path),
 		znul(vpt->fs_key_cipher), znul(vpt->fs_key_hash), znul(vpt->header), options,
-		vpt->use_fstab, vpt->uses_ssh
+		vpt->use_fstab, vpt->uses_ssh, vpt->ignore_source
 	);
 	HXmc_free(options);
 }
